/* Test CDraw and CLightTable */



#include <stdio.h>

#include "../3dfc.h"



/* Return one key code
**********************************************************/
BYTE Key ()
{
   #ifdef TRG_LINUX
   return vga_getkey ();
   #endif

   #ifdef TRG_DJGPP
   return getch ();
   #endif
}



main ()
{
   // define light levels
	DWORD
      dwNumLevels = 16;    // number of light levels
	printf ( "\nDemonstrate shaded polygons.\nUse how much light levels (recomended 16): " );
	scanf ( "%d", &dwNumLevels );

   // load bitmap and palette
   printf ( "\nLoading texture and palette...\n" );
   CTexture
      oTx1,
      oTx2;
   CMem
      oPal;
   CFilePCX
      oFile ( "texture.pcx" , oTx1, oPal );
   // scale loaded texture
   oTx2.mCreate ( 64, 64, oTx1 );
   // program palette (for debug)
   * ( oPal.m_payMem + 7 * 3 + 0 ) = 50;
   * ( oPal.m_payMem + 7 * 3 + 1 ) = 50;
   * ( oPal.m_payMem + 7 * 3 + 2 ) = 50;

   // define frame buffer
   printf ( "Creating frame buffer...\n" );
   CMem
      oFrameBuffer ( 320 * 200 );

   // define light table
   printf ( "Generating light table with %d levels...\n", dwNumLevels );
   CLightTable
      oLgT;
   oLgT.mCreate ( oPal, dwNumLevels );

   // instructions
   printf ( "Press A to increase light, Z to decrease and ESC to exit.\n" );
   printf ( "Press any key to continue.\n" );
   getchar ();

   // init graphics and program palette
   CScreen
      oS;
   oS.mCreate ( MODE_MCGA );
   oS.mSetPalette ( oPal );

   // draw object
   CDraw
      oDraw ( oLgT, 320, 200, oFrameBuffer );
   oDraw.mClear ( 0 );

   // define polygon and texture vertexes
   tagXY
      astPol [ 4 ],
      astTex [ 4 ];
   astPol [ 0 ].nX = 130;
   astPol [ 0 ].nY = 150;
   astPol [ 1 ].nX = 200;
   astPol [ 1 ].nY = 180;
   astPol [ 2 ].nX = 210;
   astPol [ 2 ].nY = 55;
   astPol [ 3 ].nX = 150;
   astPol [ 3 ].nY = 30;

   astTex [ 0 ].nX = 0;
   astTex [ 0 ].nY = 0;
   astTex [ 1 ].nX = 0;
   astTex [ 1 ].nY = oTx2.m_nHeight - 1;
   astTex [ 2 ].nX = oTx2.m_nWidth - 1;
   astTex [ 2 ].nY = oTx2.m_nHeight - 1;
   astTex [ 3 ].nX = oTx2.m_nWidth - 1;
   astTex [ 3 ].nY = 0;

   // make interactions
   BOOL
      bEnd = FALSE;
   float
      fInc = (float) 1 / dwNumLevels,   // the light is defined with values
      fLight = fInc * dwNumLevels / 2;	 // between 0 and 1
   while ( ! bEnd ) {

      oDraw.mTexturedPolygon ( astPol, astTex, 4, oTx2, NULL, fLight );

      // show frame buffer on screen
      oS.mShow ( oFrameBuffer );

		//gotoxy ( 1, 1 );
		//printf ( "%f\n", fLight );

      switch ( Key () ) {

         case 'a':
         case 'A':
            if ( fLight < 1 )
               fLight += fInc;
            break;

         case 'z':
         case 'Z':
            if ( fLight > 0 )
               fLight -= fInc;
            break;

         case 27:
            bEnd = TRUE;
      }
   }
}
